@@ -3,7 +3,7 @@ from django.urls import reverse
 from arches.app.models import models
 from arches.app.models.system_settings import settings
 from arches.app.search.elasticsearch_dsl_builder import Dsl, Bool, Terms, Exists, Nested
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 import logging
 
 logger = logging.getLogger(__name__)
@@ -14,7 +14,16 @@ class BaseDataType(object):
         self.datatype_model = model
         self.datatype_name = model.datatype if model else None
 
-    def validate(self, value, row_number=None, source=None, node=None, nodeid=None, strict=False, **kwargs):
+    def validate(
+        self,
+        value,
+        row_number=None,
+        source=None,
+        node=None,
+        nodeid=None,
+        strict=False,
+        **kwargs,
+    ):
         """
         Used to validate data in a node of given datatype
 
@@ -32,11 +41,14 @@ class BaseDataType(object):
 
         return []
 
-    def create_error_message(self, value, source, row_number, message):
+    def create_error_message(self, value, source, row_number, message, title=None):
         source_info = "{0} {1}".format(source, row_number) if row_number else ""
         error_message = {
             "type": "ERROR",
-            "message": _("{0} error, {1} {2} - {3}. Unable to save.").format(self.datatype_name, value, source_info, message),
+            "message": _("{0} error, {1} {2} - {3}. Unable to save.").format(
+                self.datatype_name, value, source_info, message
+            ),
+            "title": title,
         }
         return error_message
 
@@ -104,13 +116,22 @@ class BaseDataType(object):
         should be a dictionary including (as in map_sources table):
         name, source (json)
         """
-        tileserver_url = urllib.parse.unquote(reverse("mvt", args=(node.nodeid, "{z}", "{x}", "{y}")))
+        tileserver_url = urllib.parse.unquote(
+            reverse("mvt", args=(node.nodeid, "{z}", "{x}", "{y}"))
+        )
         if node is None:
             return None
         source_config = {"type": "vector", "tiles": [tileserver_url]}
+        node_config = json.loads(node.config.value)
+        for prop in ("minzoom", "maxzoom"):
+            if prop in node_config:
+                source_config[prop] = node_config[prop]
+
         count = None
         if preview == True:
-            count = models.TileModel.objects.filter(nodegroup_id=node.nodegroup_id, data__has_key=str(node.nodeid)).count()
+            count = models.TileModel.objects.filter(
+                nodegroup_id=node.nodegroup_id, data__has_key=str(node.nodeid)
+            ).count()
             if count == 0:
                 source_config = {
                     "type": "geojson",
@@ -120,12 +141,21 @@ class BaseDataType(object):
                             {
                                 "type": "Feature",
                                 "properties": {"total": 1},
-                                "geometry": {"type": "Point", "coordinates": [-122.4810791015625, 37.93553306183642]},
+                                "geometry": {
+                                    "type": "Point",
+                                    "coordinates": [
+                                        -122.4810791015625,
+                                        37.93553306183642,
+                                    ],
+                                },
                             },
                             {
                                 "type": "Feature",
                                 "properties": {"total": 100},
-                                "geometry": {"type": "Point", "coordinates": [-58.30078125, -18.075412438417395]},
+                                "geometry": {
+                                    "type": "Point",
+                                    "coordinates": [-58.30078125, -18.075412438417395],
+                                },
                             },
                             {
                                 "type": "Feature",
@@ -177,7 +207,12 @@ class BaseDataType(object):
                         ],
                     },
                 }
-        return {"nodeid": node.nodeid, "name": "resources-%s" % node.nodeid, "source": json.dumps(source_config), "count": count}
+        return {
+            "nodeid": node.nodeid,
+            "name": "resources-%s" % node.nodeid,
+            "source": json.dumps(source_config),
+            "count": count,
+        }
 
     def get_pref_label(self, nodevalue):
         """
@@ -192,21 +227,19 @@ class BaseDataType(object):
         except:
             data = tile["data"]
             provisionaledits = tile["provisionaledits"]
-        if data is not None and len(list(data.keys())) > 0:
+        if data is not None and any(val is not None for val in data.values()):
             return data
         elif provisionaledits is not None and len(list(provisionaledits.keys())) > 0:
             if len(list(provisionaledits.keys())) > 1:
                 logger.warning(_("Multiple provisional edits. Returning first edit"))
             userid = list(provisionaledits.keys())[0]
             return provisionaledits[userid]["value"]
-        else:
+        elif not data:
             logger.exception(_("Tile has no authoritative or provisional data"))
+        else:
+            return data
 
-
-    def get_display_value(self, tile, node, **kwargs):
-        """
-        Returns a list of concept values for a given node
-        """
+    def get_display_value(self, tile, node, **kwargs) -> str:
         data = self.get_tile_data(tile)
 
         if data:
@@ -214,6 +247,7 @@ class BaseDataType(object):
 
             if display_value:
                 return str(display_value)
+        return ""  # TODO (arches_version): configure this with a setting in 8.1
 
     def get_search_terms(self, nodevalue, nodeid=None):
         """
@@ -232,25 +266,28 @@ class BaseDataType(object):
         """
         Appends the search query dsl to search for fields that have not been populated
         """
-        base_query = Bool()
-        base_query.filter(Terms(field="graph_id", terms=[str(node.graph_id)]))
 
-        null_query = Bool()
-        data_exists_query = Exists(field="tiles.data.%s" % (str(node.pk)))
-        nested_query = Nested(path="tiles", query=data_exists_query)
-        null_query.must(nested_query)
-        if value["op"] == "null":
+        query.filter(Terms(field="graph_id", terms=[str(node.graph_id)]))
+
+        data_exists_query = Exists(field=f"tiles.data.{str(node.pk)}")
+        tiles_w_node_exists = Nested(path="tiles", query=data_exists_query)
+        if value["op"] == "not_null":
+            query.must(tiles_w_node_exists)
+        elif value["op"] == "null":
             # search for tiles that don't exist
-            exists_query = Bool()
-            exists_query.must_not(null_query)
-            base_query.should(exists_query)
+            null_query = Bool()
+            null_query.must_not(tiles_w_node_exists)
+            query.should(null_query)
 
             # search for tiles that do exist, but that have null or [] as values
+            exists_query = Bool()
+            exists_query.must(tiles_w_node_exists)
+            exists_query.must(Terms(field="graph_id", terms=[str(node.graph_id)]))
             func_query = Dsl()
             func_query.dsl = {
                 "function_score": {
                     "min_score": 1,
-                    "query": {"match_all": {}},
+                    "query": exists_query.dsl,
                     "functions": [
                         {
                             "script_score": {
@@ -258,9 +295,9 @@ class BaseDataType(object):
                                     "source": """
                                     int null_docs = 0;
                                     for(tile in params._source.tiles){
-                                        if(tile.data.containsKey(params.node_id)){
+                                        if(tile.nodegroup_id == params.nodegroup_id ){
                                             def val = tile.data.get(params.node_id);
-                                            if (val == null || (val instanceof List && val.length==0)) {
+                                            if (val == null || val == "" || (val instanceof List && val.length==0)) {
                                                 null_docs++;
                                                 break;
                                             }
@@ -269,7 +306,10 @@ class BaseDataType(object):
                                     return null_docs;
                                 """,
                                     "lang": "painless",
-                                    "params": {"node_id": "%s" % (str(node.pk))},
+                                    "params": {
+                                        "node_id": f"{str(node.pk)}",
+                                        "nodegroup_id": f"{str(node.nodegroup_id)}",
+                                    },
                                 }
                             }
                         }
@@ -279,10 +319,7 @@ class BaseDataType(object):
                     "boost_mode": "replace",
                 }
             }
-            base_query.should(func_query)
-        elif value["op"] == "not_null":
-            base_query.must(null_query)
-        query.must(base_query)
+            query.should(func_query)
 
     def pre_tile_save(self, tile, nodeid):
         """
@@ -357,10 +394,22 @@ class BaseDataType(object):
         g.add((edge_info["d_uri"], RDF.type, URIRef(edge.domainnode.ontologyclass)))
 
         if edge_info["domain_tile_data"] is not None:
-            g.add((edge_info["d_uri"], RDF.value, Literal(JSONSerializer().serialize(edge_info["domain_tile_data"]))))
+            g.add(
+                (
+                    edge_info["d_uri"],
+                    RDF.value,
+                    Literal(JSONSerializer().serialize(edge_info["domain_tile_data"])),
+                )
+            )
 
         if edge_info["range_tile_data"] is not None:
-            g.add((edge_info["r_uri"], RDF.value, Literal(JSONSerializer().serialize(edge_info["range_tile_data"]))))
+            g.add(
+                (
+                    edge_info["r_uri"],
+                    RDF.value,
+                    Literal(JSONSerializer().serialize(edge_info["range_tile_data"])),
+                )
+            )
 
         return g
 
@@ -377,6 +426,13 @@ class BaseDataType(object):
 
         return False
 
+    def get_nodevalues(self, nodevalue):
+        if nodevalue is None:
+            return []
+        elif not isinstance(nodevalue, (list, tuple)):
+            return [nodevalue]
+        return nodevalue
+
     def ignore_keys(self):
         """
         Each entry returned in the array is a string, consisting of the combination of two full URIs
@@ -401,7 +457,10 @@ class BaseDataType(object):
         Default mapping if not specified is a text field
         """
 
-        text_mapping = {"type": "text", "fields": {"keyword": {"ignore_above": 256, "type": "keyword"}}}
+        text_mapping = {
+            "type": "text",
+            "fields": {"keyword": {"ignore_above": 256, "type": "keyword"}},
+        }
         return text_mapping
 
     def get_es_mapping(self, nodeid):
@@ -416,7 +475,9 @@ class BaseDataType(object):
                 "properties": {
                     "tiles": {
                         "type": "nested",
-                        "properties": {"data": {"properties": {str(nodeid): default_mapping}}},
+                        "properties": {
+                            "data": {"properties": {str(nodeid): default_mapping}}
+                        },
                     }
                 }
             }
@@ -461,3 +522,11 @@ class BaseDataType(object):
         Adds properties to a tile necessary for some clients, but not essential to the tile
         """
         pass
+
+    def validate_node(self, node):
+        """
+        Confirms a node is properly configured to collect data.
+        If improperly configured, this method should raise
+        a GraphValidationError
+        """
+        pass
