@@ -76,7 +76,9 @@ class BaseConceptDataType(BaseDataType):
             return self.value_lookup[valueid]
         except:
             try:
-                self.value_lookup[valueid] = models.Value.objects.get(pk=valueid)
+                self.value_lookup[valueid] = models.Value.objects.select_related(
+                    "concept", "valuetype"
+                ).get(pk=valueid)
                 return self.value_lookup[valueid]
             except ObjectDoesNotExist:
                 return models.Value()
@@ -102,8 +104,7 @@ class BaseConceptDataType(BaseDataType):
         date_range = {}
         cache_value = cache.get("concept-" + str(concept.conceptid), "no result")
         if cache_value == "no result":
-            values = models.Value.objects.filter(concept=concept)
-            for value in values:
+            for value in concept.value_set.select_related("valuetype"):
                 if value.valuetype.valuetype in ("min_year", "max_year"):
                     date_range[value.valuetype.valuetype] = value.value
             if "min_year" in date_range and "max_year" in date_range:
@@ -391,9 +392,8 @@ class ConceptDataType(BaseConceptDataType):
             if value["id"]:
                 return value["id"]
             else:
-                hits = [ident for ident in models.Value.objects.all()]
-                if hits:
-                    return str(hits[0].pk)
+                if arbitrary_value := models.Value.objects.first():
+                    return str(arbitrary_value.pk)
                 else:
                     print(f"No labels for concept: {concept_id}!")
                     return None
