@@ -77,7 +77,7 @@ class DataTypeFactory(object):
         if DataTypeFactory._datatypes is None:
             DataTypeFactory._datatypes = {
                 datatype.datatype: datatype
-                for datatype in models.DDataType.objects.all()
+                for datatype in models.DDataType.objects.select_related("defaultwidget")
             }
         self.datatypes = DataTypeFactory._datatypes
         self.datatype_instances = DataTypeFactory._datatype_instances
@@ -88,7 +88,7 @@ class DataTypeFactory(object):
         except KeyError:
             DataTypeFactory._datatypes = {
                 datatype.datatype: datatype
-                for datatype in models.DDataType.objects.all()
+                for datatype in models.DDataType.objects.select_related("defaultwidget")
             }
             d_datatype = DataTypeFactory._datatypes[datatype]
             self.datatypes = DataTypeFactory._datatypes
@@ -517,6 +517,13 @@ class NumberDataType(BaseDataType):
                 "provisional": provisional,
             }
         )
+        document["strings"].append(
+            {
+                "string": str(nodevalue),
+                "nodegroup_id": tile.nodegroup_id,
+                "provisional": provisional,
+            }
+        )
 
     def append_search_filters(self, value, node, query, request):
         try:
@@ -566,6 +573,13 @@ class NumberDataType(BaseDataType):
         mapping = {"type": "double"}
         return mapping
 
+    def get_search_terms(self, nodevalue, nodeid=None):
+        terms = []
+        if nodevalue:
+            terms.append(SearchTerm(value=nodevalue))
+
+        return terms
+
 
 class BooleanDataType(BaseDataType):
     def validate(
@@ -1264,8 +1278,6 @@ class FileListDataType(BaseDataType):
             # this does not get called when saving data from the mobile app
             previously_saved_tile = models.TileModel.objects.filter(pk=tile.tileid)
             user = request.user
-            if hasattr(request.user, "userprofile") is not True:
-                models.UserProfile.objects.create(user=request.user)
             user_is_reviewer = user_is_resource_reviewer(request.user)
             current_tile_data = self.get_tile_data(tile)
             if previously_saved_tile.count() == 1:
@@ -1815,7 +1827,7 @@ class DomainDataType(BaseDomainDataType):
         This snippet will be used in a SQL UPDATE statement.
         """
 
-        sql = i18n_json_field.attname
+        sql = i18n_json_field.attname or "'{}'::jsonb"
         for prop, value in i18n_json_field.raw_value.items():
             escaped_value = json.dumps(value).replace("%", "%%").replace("'", "''")
             if prop == "options":
@@ -2031,10 +2043,10 @@ class ResourceInstanceDataType(BaseDataType):
     ):
         errors = []
         if value is not None:
-            resourceXresourceIds = self.get_nodevalues(value)
-            for resourceXresourceId in resourceXresourceIds:
+            relations = self.get_nodevalues(value)
+            for relation in relations:
                 try:
-                    resourceid = resourceXresourceId["resourceId"]
+                    resourceid = relation["resourceId"]
                     uuid.UUID(resourceid)
                     if strict:
                         try:
@@ -2238,22 +2250,32 @@ class ResourceInstanceDataType(BaseDataType):
     def transform_export_values(self, value, *args, **kwargs):
         return json.dumps(value)
 
+    def append_in_list_search_filters(self, value, node, query):
+        values_list = value.get("val", [])
+        if values_list:
+            field_name = f"tiles.data.{node.pk}"
+            for val in values_list:
+                match_q = Term(
+                    field=f"tiles.data.{node.pk}.resourceId.keyword",
+                    term=val,
+                )
+
+                match value["op"]:
+                    case "" | "in_list_any":
+                        query.should(match_q)
+                    case "in_list_all":
+                        query.must(match_q)
+                    case "!" | "in_list_none":
+                        query.must_not(match_q)
+            query.filter(Exists(field=field_name))
+
     def append_search_filters(self, value, node, query, request):
         try:
             if value["op"] == "null" or value["op"] == "not_null":
                 self.append_null_search_filters(value, node, query, request)
-            elif value["val"] != "" and value["val"] != []:
-                # search_query = Match(field="tiles.data.%s.resourceId" % (str(node.pk)), type="phrase", query=value["val"])
-                search_query = Terms(
-                    field="tiles.data.%s.resourceId.keyword" % (str(node.pk)),
-                    terms=value["val"],
-                )
-                if "!" in value["op"]:
-                    query.must_not(search_query)
-                    query.filter(Exists(field="tiles.data.%s" % (str(node.pk))))
-                else:
-                    query.must(search_query)
-        except KeyError:
+            else:
+                self.append_in_list_search_filters(value, node, query)
+        except KeyError as e:
             pass
 
     def get_rdf_uri(self, node, data, which="r"):
@@ -2366,23 +2388,33 @@ class ResourceInstanceListDataType(ResourceInstanceDataType):
             Resource,
         )  # import here rather than top to avoid circular import
 
-        resourceid = None
         data = self.get_tile_data(tile)
         if data:
             nodevalue = self.get_nodevalues(data[str(node.nodeid)])
             items = []
 
+            other_resource_ids: set[uuid.UUID] = set()
             for resourceXresource in nodevalue:
                 try:
-                    resourceid = resourceXresource["resourceId"]
-                    related_resource = Resource.objects.get(pk=resourceid)
-                    displayname = related_resource.displayname()
-                    resourceXresource["display_value"] = displayname
-                    items.append(resourceXresource)
-                except (TypeError, KeyError):
+                    other_resource_ids.add(uuid.UUID(resourceXresource["resourceId"]))
+                except (TypeError, ValueError, KeyError):
                     pass
-                except:
-                    logger.info(f'Resource with id "{resourceid}" not in the system.')
+            other_resources = Resource.objects.filter(pk__in=other_resource_ids)
+            for resourceXresource in nodevalue:
+                tileResourceId = uuid.UUID(resourceXresource["resourceId"])
+                for candidate in other_resources:
+                    if candidate.pk == tileResourceId:
+                        related_resource = candidate
+                        break
+                else:
+                    logger.info(
+                        f'Resource with id "{tileResourceId}" not in the system.'
+                    )
+                    continue
+                displayname = related_resource.displayname()
+                resourceXresource["display_value"] = displayname
+                items.append(resourceXresource)
+
             return self.compile_json(tile, node, instance_details=items)
 
     def collects_multiple_values(self):
