@@ -15,45 +15,22 @@ You should have received a copy of the GNU Affero General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 """
 
+import ast
 import re
 import json
 from arches.app.models.system_settings import settings
 from arches.app.datatypes.base import BaseDataType
-from arches.app.models.models import Widget
 from arches.app.search.elasticsearch_dsl_builder import Match, Exists, Term
 from arches.app.search.search_term import SearchTerm
 
 from rdflib import ConjunctiveGraph as Graph
 from rdflib import URIRef, Literal, Namespace
 from rdflib.namespace import RDF, RDFS, XSD, DC, DCTERMS
+from django.utils.translation import gettext as _
 
 archesproject = Namespace(settings.ARCHES_NAMESPACE_FOR_DATA_EXPORT)
 cidoc_nm = Namespace("http://www.cidoc-crm.org/cidoc-crm/")
 
-import logging
-
-logger = logging.getLogger(__name__)
-
-default_widget_name = "urldatatype"
-default_url_widget = None
-try:
-    default_url_widget = Widget.objects.get(name=default_widget_name)
-except Widget.DoesNotExist as e:
-    logger.warn("Setting 'url' datatype's default widget to None ({0} widget not found).".format(default_widget_name))
-
-details = {
-    "datatype": "url",
-    "iconclass": "fa fa-location-arrow",
-    "modulename": "url.py",
-    "classname": "URLDataType",
-    "defaultwidget": default_url_widget,
-    "defaultconfig": None,
-    "configcomponent": "views/components/datatypes/url",
-    "configname": "url-datatype-config",
-    "isgeometric": False,
-    "issearchable": True,
-}
-
 
 class FailRegexURLMatch(Exception):
     pass
@@ -64,31 +41,46 @@ class URLDataType(BaseDataType):
     URL Datatype to store an optionally labelled hyperlink to a (typically) external resource
     """
 
-    URL_REGEX = re.compile(r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)")
+    URL_REGEX = re.compile(
+        r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)"
+    )
 
-    def validate(self, value, row_number=None, source=None, node=None, nodeid=None, strict=False, **kwargs):
+    def validate(
+        self,
+        value,
+        row_number=None,
+        source=None,
+        node=None,
+        nodeid=None,
+        strict=False,
+        **kwargs,
+    ):
         errors = []
+
         if value is not None:
             try:
-                if value.get("url") is not None:
+                if value.get("url"):
                     # check URL conforms to URL structure
                     url_test = self.URL_REGEX.match(value["url"])
                     if url_test is None:
                         raise FailRegexURLMatch
             except FailRegexURLMatch:
-                errors.append(
-                    {
-                        "type": "ERROR",
-                        "message": "datatype: {0} value: {1} {2} {3} - {4}. {5}".format(
-                            self.datatype_model.datatype,
-                            value,
-                            source,
-                            row_number,
-                            "this is not a valid HTTP/HTTPS URL",
-                            "This data was not imported.",
-                        ),
-                    }
+                message = _("This is not a valid HTTP/HTTPS URL")
+                title = _("Invalid HTTP/HTTPS URL")
+                error_message = self.create_error_message(
+                    value, source, row_number, message, title
                 )
+                errors.append(error_message)
+
+            # raise error if label added without URL (#10592)
+            if value.get("url_label") and not value.get("url"):
+                message = _("URL label cannot be saved without a URL")
+                title = _("No URL added")
+                error_message = self.create_error_message(
+                    value, source, row_number, message, title
+                )
+                errors.append(error_message)
+
         return errors
 
     def transform_value_for_tile(self, value, **kwargs):
@@ -100,17 +92,23 @@ class URLDataType(BaseDataType):
         a json string like '{"url": "", "url_label": ""}'
         """
 
-        ret = {"url": "", "url_label": ""}
-
         try:
-            ret = json.loads(value)
+            return json.loads(value)
+        except ValueError:
+            # do this if json (invalid) is formatted with single quotes, re #6390
+            try:
+                return ast.literal_eval(value)
+            except:
+                if isinstance(value, dict):
+                    return value
+                else:
+                    return {"url": value, "url_label": ""}
         except BaseException:
+            # this will probably fail validation, but that is ok. We need the error to report the value.
             if isinstance(value, dict):
-                ret = value
+                return value
             else:
-                ret["url"] = value
-
-        return ret
+                return {"url": value, "url_label": ""}
 
     def get_display_value(self, tile, node, **kwargs):
         data = self.get_tile_data(tile)
@@ -119,11 +117,13 @@ class URLDataType(BaseDataType):
 
             if display_value:
                 return json.dumps(display_value)
+        return ""
 
     def to_json(self, tile, node):
         data = self.get_tile_data(tile)
+        value_data = data.get(str(node.nodeid)) or {}
         if data:
-            return self.compile_json(tile, node, **data.get(str(node.nodeid)))
+            return self.compile_json(tile, node, **value_data)
 
     def append_to_document(self, document, nodevalue, nodeid, tile, provisional=False):
         if nodevalue.get("url") is not None:
@@ -147,25 +147,29 @@ class URLDataType(BaseDataType):
         terms = []
         if nodevalue.get("url") is not None:
             if nodevalue.get("url_label") is not None:
-                if settings.WORDS_PER_SEARCH_TERM is None or (len(nodevalue["url_label"].split(" ")) < settings.WORDS_PER_SEARCH_TERM):
+                if settings.WORDS_PER_SEARCH_TERM is None or (
+                    len(nodevalue["url_label"].split(" "))
+                    < settings.WORDS_PER_SEARCH_TERM
+                ):
                     terms.append(SearchTerm(value=nodevalue["url_label"]))
             # terms.append(nodevalue['url'])       FIXME: URLs searchable?
         return terms
 
     def append_search_filters(self, value, node, query, request):
         # Match the label in the same manner as a String datatype
-
         try:
             if value["val"] != "":
-                match_type = "phrase_prefix" if "~" in value["op"] else "phrase"
                 if "~" in value["op"]:
                     match_query = Match(
                         field="tiles.data.%s.url" % (str(node.pk)),
                         query=value["val"],
-                        type=match_type,
+                        type="phrase_prefix",
+                    )
+                if "eq" in value["op"]:
+                    match_query = Term(
+                        field="tiles.data.%s.url.keyword" % (str(node.pk)),
+                        term=value["val"],
                     )
-                if "=" in value["op"]:
-                    match_query = Term(field="tiles.data.%s.url.keyword" % (str(node.pk)), term=value["val"])
                 if "!" in value["op"]:
                     query.must_not(match_query)
                     query.filter(Exists(field="tiles.data.%s" % (str(node.pk))))
@@ -175,11 +179,14 @@ class URLDataType(BaseDataType):
             pass
 
     def get_rdf_uri(self, node, data, which="r"):
-        return URIRef(data["url"])
+        if data and "url" in data:
+            return URIRef(data["url"])
+        return None
 
     def accepts_rdf_uri(self, uri):
         return self.URL_REGEX.match(uri) and not (
-            uri.startswith("urn:uuid:") or uri.startswith(settings.ARCHES_NAMESPACE_FOR_DATA_EXPORT + "resources/")
+            uri.startswith("urn:uuid:")
+            or uri.startswith(settings.ARCHES_NAMESPACE_FOR_DATA_EXPORT + "resources/")
         )
 
     def is_a_literal_in_rdf(self):
@@ -188,13 +195,18 @@ class URLDataType(BaseDataType):
 
     def ignore_keys(self):
         # We process label into the datatype, so downstream processing should ignore it.
-        return ["http://www.w3.org/2000/01/rdf-schema#label http://www.w3.org/2000/01/rdf-schema#Literal"]
+        return [
+            "http://www.w3.org/2000/01/rdf-schema#label http://www.w3.org/2000/01/rdf-schema#Literal"
+        ]
 
     def to_rdf(self, edge_info, edge):
         # returns an in-memory graph object, containing the domain resource, its
         # type and the string as a string literal
         g = Graph()
-        if edge_info["range_tile_data"] is not None and edge_info["range_tile_data"].get("url") is not None:
+        if (
+            edge_info["range_tile_data"] is not None
+            and edge_info["range_tile_data"].get("url") is not None
+        ):
             g.add((edge_info["d_uri"], RDF.type, URIRef(edge.domainnode.ontologyclass)))
             g.add(
                 (
@@ -235,7 +247,9 @@ class URLDataType(BaseDataType):
             value["url"] = url_node["@id"]
             value["url_label"] = None
             if "http://www.w3.org/2000/01/rdf-schema#label" in url_node:
-                value["url_label"] = url_node["http://www.w3.org/2000/01/rdf-schema#label"][0]["@value"]
+                value["url_label"] = url_node[
+                    "http://www.w3.org/2000/01/rdf-schema#label"
+                ][0]["@value"]
         except (IndexError, AttributeError, KeyError) as e:
             print(f"Broke trying to import url datatype: {json_ld_node}")
             return None
@@ -258,3 +272,19 @@ class URLDataType(BaseDataType):
                 },
             }
         }
+
+    def pre_tile_save(self, tile, nodeid):
+        if (tile_val := tile.data[nodeid]) and "url_label" not in tile_val:
+            tile_val["url_label"] = ""
+
+    def clean(self, tile, nodeid):
+        if data := tile.data[nodeid]:
+            try:
+                if not any([val.strip() for val in data.values()]):
+                    tile.data[nodeid] = None
+            except:
+                pass  # Let self.validate handle malformed data
+
+    def pre_structure_tile_data(self, tile, nodeid, **kwargs):
+        if (tile_val := tile.data[nodeid]) and "url_label" not in tile_val:
+            tile_val["url_label"] = ""
