@@ -86,7 +86,7 @@ class BaseBulkEditor:
             GraphModel.objects.all()
             .exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
             .exclude(isresource=False)
-            .exclude(publication_id__isnull=True)
+            .exclude(source_identifier__isnull=False)
             .order_by(graph_name_i18n)
         )
         return {"success": True, "data": graphs}
