@@ -19,6 +19,15 @@ class BaseFunction(object):
     def on_import(self, *args, **kwargs):
         raise NotImplementedError
 
+    def on_update_lifecycle_state(
+        self, resource_instance, current_state, new_state, request=None, context=None
+    ):
+        """
+        Called on update of the lifecycle state of a resource instance.
+        This method should be overridden by subclasses to implement specific logic.
+        """
+        raise NotImplementedError
+
     # saves changes to the function itself
     def after_function_save(self, *args, **kwargs):
         raise NotImplementedError
