@@ -19,10 +19,7 @@ along with this program. If not, see <http://www.gnu.org/licenses/>.
 import uuid
 from django.db import transaction
 from django.db.models import Q
-from django.core.exceptions import ObjectDoesNotExist, ValidationError
-from django.forms import ModelForm
-from django.utils.translation import gettext as _
-
+from django.core.exceptions import ObjectDoesNotExist
 from arches.app.models import models
 from arches.app.utils.betterJSONSerializer import JSONSerializer
 
@@ -35,6 +32,7 @@ class Card(models.CardModel):
 
     class Meta:
         proxy = True
+        ordering = ["sortorder"]
 
     def update_constraints(self, constraints):
         def add_nodeconstraints(nodeids, constraint_model):
@@ -141,7 +139,6 @@ class Card(models.CardModel):
                         "cards",
                         "widgets",
                         "nodes",
-                        "is_editable",
                         "nodegroup",
                         "constraints",
                     ):
@@ -151,7 +148,7 @@ class Card(models.CardModel):
                     for card in args[0]["cards"]:
                         self.cards.append(Card(card))
 
-                if "constraints":
+                if "constraints" in args[0]:
                     self.update_constraints(args[0]["constraints"])
 
                 if "widgets" in args[0]:
@@ -204,23 +201,12 @@ class Card(models.CardModel):
 
         """
         with transaction.atomic():
-            if self.graph.publication_id:
-                ret = {
-                    "title": _("Unable to Save Card"),
-                    "message": _(
-                        "You cannot edit a card in a published graph.  Please unpublish the graph before editing."
-                    ),
-                }
-                raise ValidationError(ret)
-            if self.graph.ontology and self.graph.isresource:
+            if self.graph.ontology_id and self.graph.isresource:
                 edge = self.get_edge_to_parent()
                 if self.ontologyproperty is not None:
                     edge.ontologyproperty = self.ontologyproperty
                 edge.save()
 
-            self.nodegroup.cardinality = self.cardinality
-            self.nodegroup.save()
-
             super(Card, self).save()
             for widget in self.widgets:
                 widget.save()
@@ -289,11 +275,6 @@ class Card(models.CardModel):
         ret["active"] = (
             self.active if "active" not in exclude else ret.pop("active", None)
         )
-        ret["is_editable"] = (
-            self.is_editable()
-            if "is_editable" not in exclude
-            else ret.pop("is_editable", None)
-        )
         ret["ontologyproperty"] = (
             self.ontologyproperty
             if "ontologyproperty" not in exclude
@@ -307,7 +288,7 @@ class Card(models.CardModel):
             if "constraints" not in exclude
             else ret.pop("constraints", None)
         )
-        if self.graph and self.graph.ontology and self.graph.isresource:
+        if self.graph and self.graph.ontology_id and self.graph.isresource:
             edge = self.get_edge_to_parent()
             ret["ontologyproperty"] = edge.ontologyproperty
 
@@ -340,9 +321,3 @@ class Card(models.CardModel):
             ret.pop("widgets", None)
 
         return ret
-
-
-class CardXNodeXWidgetForm(ModelForm):
-    class Meta:
-        model = models.CardXNodeXWidget
-        fields = "__all__"
