@@ -1,12 +1,10 @@
-
-
 from django.db import migrations, models
 
 
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('models', '5076_adds_map_card_configs'),
+        ("models", "5076_adds_map_card_configs"),
     ]
 
     operations = [
