@@ -23,16 +23,17 @@ from time import time
 from uuid import UUID
 from types import SimpleNamespace
 from django.db import transaction
-from django.db.models import Count, F, Q
+from django.db.models import Count, F, Prefetch, Q
 from django.contrib.auth.models import User, Group
 from django.forms.models import model_to_dict
-from django.core.exceptions import ObjectDoesNotExist
+from django.core.exceptions import ObjectDoesNotExist, PermissionDenied
 from django.utils.translation import gettext as _
 from django.utils.translation import get_language
 from arches.app.models import models
 from arches.app.models.models import EditLog
 from arches.app.models.models import TileModel
 from arches.app.models.system_settings import settings
+from arches.app.models.utils import add_to_update_fields
 from arches.app.search.search_engine_factory import SearchEngineInstance as se
 from arches.app.search.mappings import TERMS_INDEX, RESOURCES_INDEX
 from arches.app.search.elasticsearch_dsl_builder import Query, Bool, Terms, Nested
@@ -40,9 +41,11 @@ from arches.app.search.es_mapping_modifier import EsMappingModifierFactory
 from arches.app.tasks import index_resource
 from arches.app.utils import import_class_from_string, task_management
 from arches.app.utils import permission_backend
+from arches.app.utils.i18n import rank_label
 from arches.app.utils.label_based_graph import LabelBasedGraph
 from arches.app.utils.label_based_graph_v2 import LabelBasedGraph as LabelBasedGraphV2
 from arches.app.utils.permission_backend import (
+    assign_perm,
     remove_perm,
 )
 from arches.app.utils.betterJSONSerializer import JSONSerializer, JSONDeserializer
@@ -55,10 +58,6 @@ from arches.app.utils.permission_backend import (
     get_filtered_instances,
     get_nodegroups_by_perm,
 )
-from arches.app.utils.resource_relationship_utils import (
-    get_resource_relationship_type_label,
-)
-
 import django.dispatch
 from arches.app.datatypes.datatypes import DataTypeFactory
 
@@ -223,23 +222,18 @@ class Resource(models.ResourceInstance):
     def displayname(self, context=None):
         return self.get_descriptor("name", context)
 
-    def save_edit(self, user={}, note="", edit_type="", transaction_id=None):
-        timestamp = datetime.datetime.now()
-        edit = EditLog()
-        edit.resourceclassid = self.graph_id
-        edit.resourceinstanceid = self.resourceinstanceid
-        edit.userid = getattr(user, "id", "")
-        edit.user_email = getattr(user, "email", "")
-        edit.user_firstname = getattr(user, "first_name", "")
-        edit.user_lastname = getattr(user, "last_name", "")
-        edit.note = note
-        edit.timestamp = timestamp
-        if transaction_id is not None:
-            edit.transactionid = transaction_id
-        edit.edittype = edit_type
-        edit.save()
-
-    def save(self, *args, **kwargs):
+    def save(
+        self,
+        *,
+        context=None,
+        index=True,
+        request=None,
+        transaction_id=None,
+        user=None,
+        should_update_resource_instance_lifecycle_state=False,
+        current_resource_instance_lifecycle_state=None,
+        **kwargs,
+    ):
         """
         Saves and indexes a single resource
 
@@ -249,17 +243,10 @@ class Resource(models.ResourceInstance):
         index -- True(default) to index the resource, otherwise don't index the resource
 
         """
-        # TODO: 7783 cbyrd throw error if graph is unpublished
         # This initializes serialized graph (for use in superclass?). Setup for the above. NOt sure
         if not self.get_serialized_graph():
             pass
 
-        request = kwargs.pop("request", None)
-        user = kwargs.pop("user", None)
-        index = kwargs.pop("index", True)
-        context = kwargs.pop("context", None)
-        transaction_id = kwargs.pop("transaction_id", None)
-
         if request is None:
             if user is None:
                 user = {}
@@ -268,8 +255,23 @@ class Resource(models.ResourceInstance):
 
         if not self.principaluser_id and user:
             self.principaluser_id = user.id
+            add_to_update_fields(kwargs, "principaluser_id")
+
+        super(Resource, self).save(
+            context=context,
+            index=index,
+            request=request,
+            transaction_id=transaction_id,
+            user=user,
+            should_update_resource_instance_lifecycle_state=should_update_resource_instance_lifecycle_state,
+            current_resource_instance_lifecycle_state=current_resource_instance_lifecycle_state,
+            **kwargs,
+        )
+
+        if should_update_resource_instance_lifecycle_state:
+            # Saving tiles at the same time as updating lifecycle state is not supported.
+            return
 
-        super(Resource, self).save(*args, **kwargs)
         self.save_edit(user=user, edit_type="create", transaction_id=transaction_id)
 
         for tile in self.tiles:
@@ -298,7 +300,7 @@ class Resource(models.ResourceInstance):
             self.tiles = [
                 tile
                 for tile in self.tiles
-                if tile.nodegroup is not None
+                if tile.nodegroup_id is not None
                 and tile.nodegroup_id in readable_nodegroups
             ]
 
@@ -389,7 +391,7 @@ class Resource(models.ResourceInstance):
 
     def index(self, context=None):
         """
-        Indexes all the nessesary items values of a resource to support search
+        Indexes all the necessary items values of a resource to support search
 
         Keyword Arguments:
         context -- a string such as "copy" to indicate conditions under which a document is indexed
@@ -412,6 +414,7 @@ class Resource(models.ResourceInstance):
             )
             document["root_ontology_class"] = self.get_root_ontology()
             doc = JSONSerializer().serializeToPython(document)
+
             se.index_data(index=RESOURCES_INDEX, body=doc, id=self.pk)
             for term in terms:
                 se.index_data("terms", body=term["_source"], id=term["_id"])
@@ -444,7 +447,13 @@ class Resource(models.ResourceInstance):
             resource_indexed.send(sender=self.__class__, instance=self)
 
     def get_documents_to_index(
-        self, fetchTiles=True, datatype_factory=None, node_datatypes=None, context=None
+        self,
+        fetchTiles=True,
+        datatype_factory=None,
+        node_datatypes=None,
+        context=None,
+        *,
+        all_users=None,
     ):
         """
         Gets all the documents nessesary to index a single resource
@@ -455,6 +464,7 @@ class Resource(models.ResourceInstance):
         datatype_factory -- refernce to the DataTypeFactory instance
         node_datatypes -- a dictionary of datatypes keyed to node ids
         context -- a string such as "copy" to indicate conditions under which a document is indexed
+        all_users -- an iterable of User objects, e.g. User.objects.prefetch_related("groups")
 
         """
 
@@ -466,10 +476,24 @@ class Resource(models.ResourceInstance):
         document["displayname"] = None
         document["root_ontology_class"] = self.get_root_ontology()
         document["legacyid"] = self.legacyid
+        document["resource_instance_lifecycle_state_id"] = str(
+            self.resource_instance_lifecycle_state_id
+        )
 
         document["displayname"] = []
         document["displaydescription"] = []
         document["map_popup"] = []
+        document["date_created"] = self.createdtime
+        try:
+            document["date_last_edited"] = (
+                models.EditLog.objects.filter(
+                    resourceinstanceid=self.resourceinstanceid, timestamp__isnull=False
+                )
+                .latest("timestamp")
+                .timestamp
+            )
+        except ObjectDoesNotExist:
+            document["date_last_edited"] = None
         for lang in settings.LANGUAGES:
             if context is None:
                 context = {}
@@ -530,7 +554,9 @@ class Resource(models.ResourceInstance):
                 [int(self.principaluser_id)] if self.principaluser_id else []
             )
         }
-        document["permissions"].update(permission_backend.get_index_values(self))
+        document["permissions"].update(
+            permission_backend.get_index_values(self, all_users=all_users)
+        )
 
         document["strings"] = []
         document["dates"] = []
@@ -645,7 +671,6 @@ class Resource(models.ResourceInstance):
         # - that the index for the to-be-deleted resource gets deleted
 
         permit_deletion = False
-        # TODO: 7783 cbyrd throw error if graph is unpublished
         if user != {}:
             user_is_reviewer = user_is_resource_reviewer(user)
             if user_is_reviewer is False:
@@ -673,8 +698,8 @@ class Resource(models.ResourceInstance):
 
         if permit_deletion is True:
             for related_resource in models.ResourceXResource.objects.filter(
-                Q(resourceinstanceidfrom=self.resourceinstanceid)
-                | Q(resourceinstanceidto=self.resourceinstanceid)
+                Q(from_resource_id=self.resourceinstanceid)
+                | Q(to_resource_id=self.resourceinstanceid)
             ):
                 related_resource.delete(deletedResourceId=self.resourceinstanceid)
 
@@ -708,7 +733,13 @@ class Resource(models.ResourceInstance):
         else:
             instance = Resource(pk=resourceinstanceid)
             # ensure PK is UUID
-            instance.clean_fields(exclude=["graph", "graph_publication"])
+            instance.clean_fields(
+                exclude=[
+                    "graph",
+                    "graph_publication",
+                    "resource_instance_lifecycle_state",
+                ]
+            )
         resourceinstanceid = str(resourceinstanceid)
 
         # delete any related terms
@@ -798,7 +829,8 @@ class Resource(models.ResourceInstance):
                 models.GraphModel.objects.all()
                 .exclude(pk=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
                 .exclude(isresource=False)
-                .exclude(publication=None)
+                .exclude(is_active=False)
+                .exclude(source_identifier__isnull=False)
             )
 
         graph_lookup = {
@@ -828,17 +860,17 @@ class Resource(models.ResourceInstance):
             limit,
             resourceinstance_graphid=None,
         ):
-            final_query = Q(resourceinstanceidfrom_id=resourceinstanceid) | Q(
-                resourceinstanceidto_id=resourceinstanceid
+            final_query = Q(from_resource_id=resourceinstanceid) | Q(
+                to_resource_id=resourceinstanceid
             )
 
             if resourceinstance_graphid:
-                to_graph_id_filter = Q(
-                    resourceinstancefrom_graphid_id=str(self.graph_id)
-                ) & Q(resourceinstanceto_graphid_id=resourceinstance_graphid)
+                to_graph_id_filter = Q(from_resource_graph_id=str(self.graph_id)) & Q(
+                    to_resource_graph_id=resourceinstance_graphid
+                )
                 from_graph_id_filter = Q(
-                    resourceinstancefrom_graphid_id=resourceinstance_graphid
-                ) & Q(resourceinstanceto_graphid_id=str(self.graph_id))
+                    from_resource_graph_id=resourceinstance_graphid
+                ) & Q(to_resource_graph_id=str(self.graph_id))
                 final_query = final_query & (to_graph_id_filter | from_graph_id_filter)
 
             return (
@@ -869,8 +901,8 @@ class Resource(models.ResourceInstance):
         )
         all_resource_ids = set()
         for relation in resource_relations["relations"]:
-            all_resource_ids.add(str(relation.resourceinstanceidto_id))
-            all_resource_ids.add(str(relation.resourceinstanceidfrom_id))
+            all_resource_ids.add(str(relation.to_resource_id))
+            all_resource_ids.add(str(relation.from_resource_id))
         exclusive_set, filtered_instances = get_filtered_instances(
             user, se, resources=list(all_resource_ids)
         )
@@ -879,13 +911,13 @@ class Resource(models.ResourceInstance):
 
         for relation in resource_relations["relations"]:
             relation = model_to_dict(relation)
-            resourceid_to = relation["resourceinstanceidto"]
-            resourceid_from = relation["resourceinstanceidfrom"]
-            resourceinstanceto_graphid = relation["resourceinstanceto_graphid"]
-            resourceinstancefrom_graphid = relation["resourceinstancefrom_graphid"]
+            to_resource = relation["to_resource"]
+            from_resource = relation["from_resource"]
+            to_resource_graph = relation["to_resource_graph"]
+            from_resource_graph = relation["from_resource_graph"]
 
-            resourceid_to_permission = str(resourceid_to) not in filtered_instances
-            resourceid_from_permission = str(resourceid_from) not in filtered_instances
+            resourceid_to_permission = str(to_resource) not in filtered_instances
+            resourceid_from_permission = str(from_resource) not in filtered_instances
 
             if exclusive_set:
                 resourceid_to_permission = not (resourceid_to_permission)
@@ -894,8 +926,8 @@ class Resource(models.ResourceInstance):
             if (
                 resourceid_to_permission
                 and resourceid_from_permission
-                and str(resourceinstanceto_graphid) in readable_graphids
-                and str(resourceinstancefrom_graphid) in readable_graphids
+                and str(to_resource_graph) in readable_graphids
+                and str(from_resource_graph) in readable_graphids
             ):
                 permitted_relation_dicts.append(relation)
             else:
@@ -907,10 +939,36 @@ class Resource(models.ResourceInstance):
             for relation in permitted_relation_dicts
             if relation["relationshiptype"]
         }
-
-        preflabel_lookup = get_resource_relationship_type_label(
-            relationship_types, lang
+        relationship_type_values = (
+            models.Value.objects.filter(
+                value__in=relationship_types,
+            )
+            .select_related("concept")
+            .prefetch_related(
+                Prefetch(
+                    "concept__value_set",
+                    # Begin with an order, so that if rank_label()
+                    # produces ties, we still have a deterministic result.
+                    queryset=models.Value.objects.order_by("pk"),
+                ),
+            )
         )
+        preflabel_lookup = {
+            str(rel_type.pk): (
+                sorted(
+                    rel_type.concept.value_set.all(),
+                    key=lambda label: rank_label(
+                        kind=label.valuetype_id,
+                        source_lang=label.language_id,
+                        target_lang=lang,
+                    ),
+                    reverse=True,
+                )[0].value
+                if rel_type.concept.value_set.all()
+                else ""
+            )
+            for rel_type in relationship_type_values
+        }
 
         for relation in permitted_relation_dicts:
             relation["relationshiptype_label"] = preflabel_lookup.get(
@@ -918,8 +976,8 @@ class Resource(models.ResourceInstance):
             )
 
             ret["resource_relationships"].append(relation)
-            instanceids.add(str(relation["resourceinstanceidto"]))
-            instanceids.add(str(relation["resourceinstanceidfrom"]))
+            instanceids.add(str(relation["to_resource"]))
+            instanceids.add(str(relation["from_resource"]))
 
         if str(self.resourceinstanceid) in instanceids:
             instanceids.remove(str(self.resourceinstanceid))
@@ -932,35 +990,34 @@ class Resource(models.ResourceInstance):
                     for resource in related_resources["docs"]
                     if resource["found"]
                 ]
-
                 if include_rr_count:
                     to_counts = (
                         models.ResourceXResource.objects.filter(
-                            resourceinstanceidto__in=related_resource_ids
+                            to_resource__in=related_resource_ids
                         )
-                        .values("resourceinstanceidto")
-                        .annotate(to_count=Count("resourceinstanceidto"))
+                        .values("to_resource")
+                        .annotate(to_count=Count("to_resource"))
                         # ORDER BY NULLS LAST is necessary for "pipelined" GROUP BY, see
                         # https://use-the-index-luke.com/sql/sorting-grouping/indexed-group-by
-                        .order_by(F("resourceinstanceidto").asc(nulls_last=True))
+                        .order_by(F("to_resource").asc(nulls_last=True))
                     )
                     from_counts = (
                         models.ResourceXResource.objects.filter(
-                            resourceinstanceidfrom__in=related_resource_ids
+                            from_resource__in=related_resource_ids
                         )
-                        .values("resourceinstanceidfrom")
-                        .annotate(from_count=Count("resourceinstanceidfrom"))
-                        .order_by(F("resourceinstanceidfrom").asc(nulls_last=True))
+                        .values("from_resource")
+                        .annotate(from_count=Count("from_resource"))
+                        .order_by(F("from_resource").asc(nulls_last=True))
                     )
 
                     total_relations_by_resource_id: dict[UUID:int] = defaultdict(int)
                     for related_resource_count in to_counts:
                         total_relations_by_resource_id[
-                            related_resource_count["resourceinstanceidto"]
+                            related_resource_count["to_resource"]
                         ] += related_resource_count["to_count"]
                     for related_resource_count in from_counts:
                         total_relations_by_resource_id[
-                            related_resource_count["resourceinstanceidfrom"]
+                            related_resource_count["from_resource"]
                         ] += related_resource_count["from_count"]
 
                 for resource in related_resources["docs"]:
@@ -1131,6 +1188,46 @@ class Resource(models.ResourceInstance):
                 remove_perm(perm, identity, self)
         self.index()
 
+    def add_permission_to_all(self, permission):
+        groups = list(Group.objects.all())
+        users = [user for user in User.objects.all() if user.is_superuser is False]
+        for identity in groups + users:
+            assign_perm(permission, identity, self)
+        self.index()
+
+    def update_resource_instance_lifecycle_state(
+        self, user, resource_instance_lifecycle_state
+    ):
+        if not user_is_resource_reviewer(user):
+            raise PermissionDenied
+
+        if (
+            self.graph.resource_instance_lifecycle.pk
+            != resource_instance_lifecycle_state.resource_instance_lifecycle.pk
+        ):
+            raise ValueError(
+                _(
+                    "The given ResourceInstanceLifecycleState is not part of the model's ResourceInstanceLifecycle."
+                )
+            )
+
+        if (
+            self.resource_instance_lifecycle_state.pk
+            != resource_instance_lifecycle_state.pk
+        ):
+            current_resource_instance_lifecycle_state = (
+                self.resource_instance_lifecycle_state
+            )
+            self.resource_instance_lifecycle_state = resource_instance_lifecycle_state
+
+            self.save(
+                user=user,
+                current_resource_instance_lifecycle_state=current_resource_instance_lifecycle_state,
+                should_update_resource_instance_lifecycle_state=True,
+            )
+
+        return self.resource_instance_lifecycle_state
+
 
 def parse_node_value(value):
     if is_uuid(value):
@@ -1147,23 +1244,3 @@ def is_uuid(value_to_test):
         return True
     except Exception:
         return False
-
-
-class PublishedModelError(Exception):
-    def __init__(self, message, code=None):
-        self.title = _("Published Model Error")
-        self.message = message
-        self.code = code
-
-    def __str__(self):
-        return repr(self.message)
-
-
-class UnpublishedModelError(Exception):
-    def __init__(self, message, code=None):
-        self.title = _("Unpublished Model Error")
-        self.message = message
-        self.code = code
-
-    def __str__(self):
-        return repr(self.message)
