@@ -7,26 +7,30 @@ details = {
     "icon": "",
     "modulename": "provisional_filter.py",
     "classname": "ProvisionalFilter",
-    "type": "",
+    "type": "provisional-filter-type",
     "componentpath": "views/components/search/provisional-filter",
     "componentname": "provisional-filter",
-    "sortorder": "0",
-    "enabled": True,
+    "config": {},
 }
 
 
 class ProvisionalFilter(BaseSearchFilter):
-    def append_dsl(self, search_results_object, permitted_nodegroups, include_provisional):
+    def append_dsl(self, search_query_object, **kwargs):
+        include_provisional = kwargs.get("include_provisional")
         search_query = Bool()
 
         if include_provisional is not True:
             provisional_resource_filter = Bool()
 
             if include_provisional is False:
-                provisional_resource_filter.filter(Terms(field="provisional_resource", terms=["false", "partial"]))
+                provisional_resource_filter.filter(
+                    Terms(field="provisional_resource", terms=["false"])
+                )
 
             elif include_provisional == "only provisional":
-                provisional_resource_filter.filter(Terms(field="provisional_resource", terms=["true", "partial"]))
+                provisional_resource_filter.filter(
+                    Terms(field="provisional_resource", terms=["true", "partial"])
+                )
 
             search_query.must(provisional_resource_filter)
-            search_results_object["query"].add_query(search_query)
+            search_query_object["query"].add_query(search_query)
