@@ -18,19 +18,12 @@ details = {
 
 
 def get_permitted_graphids(permitted_nodegroups):
-    permitted_graphids = set()
-
-    for node in Node.objects.filter(nodegroup__in=permitted_nodegroups):
-        permitted_graphids.add(str(node.graph_id))
-
-    permitted_and_published_graphids = set(
-        str(graphid)
-        for graphid in GraphModel.objects.filter(graphid__in=permitted_graphids)
-        .exclude(publication=None)
-        .values_list("graphid", flat=True)
-    )
-
-    return permitted_and_published_graphids
+    return {
+        str(graph_id)
+        for graph_id in Node.objects.filter(nodegroup__in=permitted_nodegroups)
+        .values_list("graph_id", flat=True)
+        .distinct()
+    }
 
 
 class ResourceTypeFilter(BaseSearchFilter):
