@@ -26,7 +26,6 @@ from arches.app.search.es_mapping_modifier import EsMappingModifierFactory
 CONCEPTS_INDEX = "concepts"
 TERMS_INDEX = "terms"
 RESOURCES_INDEX = "resources"
-RESOURCE_RELATIONS_INDEX = "resource_relations"
 
 
 ANALYZER = {
@@ -145,6 +144,7 @@ def prepare_search_index(create=False):
             ],
             "properties": {
                 "graph_id": {"type": "keyword"},
+                "resource_instance_lifecycle_state_id": {"type": "keyword"},
                 "legacyid": {
                     "type": "text",
                     "fields": {"keyword": {"ignore_above": 256, "type": "keyword"}},
@@ -280,6 +280,8 @@ def prepare_search_index(create=False):
                         "provisional": {"type": "boolean"},
                     },
                 },
+                "date_created": {"type": "keyword"},
+                "date_last_edited": {"type": "keyword"},
             },
         },
     }
@@ -325,46 +327,3 @@ def prepare_search_index(create=False):
 def delete_search_index():
     se = SearchEngineFactory().create()
     se.delete_index(index=RESOURCES_INDEX)
-
-
-def prepare_resource_relations_index(create=False):
-    """
-    Creates the settings and mappings in Elasticsearch to support related resources
-
-    """
-
-    index_settings = {
-        "mappings": {
-            "properties": {
-                "resourcexid": {"type": "keyword"},
-                "notes": {"type": "text"},
-                "relationshiptype": {"type": "keyword"},
-                "inverserelationshiptype": {"type": "keyword"},
-                "resourceinstanceidfrom": {"type": "keyword"},
-                "resourceinstancefrom_graphid": {"type": "keyword"},
-                "resourceinstanceidto": {"type": "keyword"},
-                "resourceinstanceto_graphid": {"type": "keyword"},
-                "created": {"type": "keyword"},
-                "modified": {"type": "keyword"},
-                "datestarted": {"type": "date"},
-                "dateended": {"type": "date"},
-                "tileid": {"type": "keyword"},
-                "nodeid": {"type": "keyword"},
-            }
-        }
-    }
-
-    if create:
-        se = SearchEngineFactory().create()
-        se.create_index(index=RESOURCE_RELATIONS_INDEX, **index_settings)
-
-    return index_settings
-
-
-# the RESOURCE_RELATIONS_INDEX is now deprecated
-# leaving this method here so users can still remove it
-# during a reindex operation
-# TODO: remove in Arches v8
-def delete_resource_relations_index():
-    se = SearchEngineFactory().create()
-    se.delete_index(index=RESOURCE_RELATIONS_INDEX)
