@@ -1,7 +1,6 @@
 import importlib
 import os
 import logging
-import shutil
 from celery import shared_task
 from datetime import datetime
 from datetime import timedelta
@@ -9,6 +8,7 @@ from django.contrib.auth.models import User
 from django.core import management
 from django.core.exceptions import ObjectDoesNotExist
 from django.db import connection
+from django.db.models import F, Q
 from django.http import HttpRequest
 from django.utils.translation import gettext as _
 from arches.app.models import models
@@ -629,6 +629,111 @@ def reverse_etl_load(loadid):
     module.reverse_load(loadid)
 
 
+@shared_task
+def update_resource_instance_data_based_on_graph_diff(
+    initial_graph, updated_graph, user_id
+):
+    logger = logging.getLogger(__name__)
+    user = User.objects.get(id=user_id)
+
+    # TODO: update function name to be less specific
+    notify_completion(
+        _("Updating business data based on graph changes."),
+        user,
+    )
+
+    try:
+        # delete tiles whose nodegroups are no longer in the updated graph
+        updated_nodegroup_ids = {
+            nodegroup["nodegroupid"] for nodegroup in updated_graph["nodegroups"]
+        }
+        orphaned_nodegroup_ids = {
+            nodegroup["nodegroupid"]
+            for nodegroup in initial_graph["nodegroups"]
+            if nodegroup["nodegroupid"] not in updated_nodegroup_ids
+        }
+        models.TileModel.objects.filter(
+            nodegroup_id__in=orphaned_nodegroup_ids,
+            resourceinstance__graph_publication_id=initial_graph["publication_id"],
+        ).delete()
+
+        # delete tiles whose parent tile's nodegroup_id does not match the expected parent nodegroup_id
+        models.TileModel.objects.filter(
+            parenttile__isnull=False,
+            resourceinstance__graph_publication_id=initial_graph["publication_id"],
+        ).filter(
+            ~Q(parenttile__nodegroup_id=F("nodegroup__parentnodegroup_id"))
+        ).delete()
+
+        # add/remove nodes and change default values
+        resource_instances = models.ResourceInstance.objects.filter(
+            graph_publication_id=initial_graph["publication_id"]
+        )
+        resource_instance_count = resource_instances.count()
+
+        initial_node_ids_to_default_values = {}
+        for initial_widget in initial_graph["cards_x_nodes_x_widgets"]:
+            initial_node_ids_to_default_values[initial_widget["node_id"]] = (
+                initial_widget.get("config", {}).get("defaultValue")
+            )
+
+        updated_node_ids_to_default_values = {}
+        for updated_widget in updated_graph["cards_x_nodes_x_widgets"]:
+            updated_node_ids_to_default_values[updated_widget["node_id"]] = (
+                updated_widget.get("config", {}).get("defaultValue")
+            )
+
+        for tile in models.TileModel.objects.filter(
+            resourceinstance__in=resource_instances
+        ):
+            updated_node_ids = [
+                node["nodeid"]
+                for node in updated_graph["nodes"]
+                if node["nodegroup_id"] == str(tile.nodegroup_id)
+            ]
+
+            # delete nodes not in updated graph
+            for node_id in list(tile.data.keys()):
+                if node_id not in updated_node_ids:
+                    del tile.data[node_id]
+
+            # add nodes that only exist in updated graph
+            # or update nodes default value if changed
+            for node_id in updated_node_ids:
+                initial_default_value = initial_node_ids_to_default_values.get(node_id)
+
+                if (
+                    node_id not in tile.data.keys()
+                    or tile.data[node_id] == initial_default_value
+                ):
+                    tile.data[node_id] = updated_node_ids_to_default_values.get(node_id)
+
+            tile.save()
+
+        # update resource_instance publication_id
+        for resource_instance in resource_instances:
+            resource_instance.graph_publication_id = updated_graph["publication_id"]
+            resource_instance.save()
+
+        notify_completion(
+            _(
+                "Business has been updated in concurrence with publishing the latest model. {} Resource Instances updated.".format(
+                    resource_instance_count
+                )
+            ),
+            user,
+        )
+
+    except Exception as e:
+        logger.error(e)
+        notify_completion(
+            _(
+                "Business data update failed. Check the error logs for more information."
+            ),
+            user,
+        )
+
+
 def create_user_task_record(taskid, taskname, userid):
     try:
         user = User.objects.get(id=userid)
