@@ -347,5 +347,5 @@ class LanguageSynchronizer:
 
             if update_published_graphs:
                 for graph in Graph.objects.all():
-                    if graph.publication_id:
+                    if graph.publication_id and not graph.source_identifier:
                         graph.update_published_graphs()
