@@ -191,8 +191,9 @@ class LabelBasedGraph(object):
             datatype_factory = DataTypeFactory()
 
         if not serialized_graph:
-            node = models.Node.objects.get(pk=tile.nodegroup_id)
-            graph = models.GraphModel.objects.get(pk=node.graph_id)
+            graph = models.GraphModel.objects.get(
+                node__nodegroup=tile.nodegroup_id
+            ).select_related("publication")
 
             user_language = translation.get_language()
             published_graph = models.PublishedGraph.objects.get(
@@ -275,7 +276,7 @@ class LabelBasedGraph(object):
 
         user_language = translation.get_language()
         published_graph = models.PublishedGraph.objects.get(
-            publication=resource.graph.publication, language=user_language
+            publication=resource.graph_publication, language=user_language
         )
         serialized_graph = published_graph.serialized_graph
 
