@@ -4,7 +4,7 @@ from django.http import HttpResponse
 from django.contrib.auth.models import User, AnonymousUser
 from django.utils.deprecation import MiddlewareMixin
 from django.utils.functional import SimpleLazyObject
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from arches.app.models.system_settings import settings
 from arches.app.utils.response import Http401Response
 from arches.app.utils.betterJSONSerializer import JSONSerializer, JSONDeserializer
@@ -30,7 +30,9 @@ class ModifyAuthorizationHeader(MiddlewareMixin):
         # HTTP_AUTHORIZATION header. So, if the request has the alternate
         # HTTP_X_AUTHORIZATION header, update the request to use the standard
         if request.META.get("HTTP_X_AUTHORIZATION", None) is not None:
-            request.META["HTTP_AUTHORIZATION"] = request.META.get("HTTP_X_AUTHORIZATION")
+            request.META["HTTP_AUTHORIZATION"] = request.META.get(
+                "HTTP_X_AUTHORIZATION"
+            )
             del request.META["HTTP_X_AUTHORIZATION"]
 
 
