@@ -1,7 +1,7 @@
 from io import StringIO
 import logging
 from django.http import HttpResponse
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from arches.app.utils.betterJSONSerializer import JSONSerializer
 from arches.app.models.system_settings import settings
 
@@ -18,6 +18,7 @@ class JSONResponse(HttpResponse):
         sort_keys = kwargs.pop("sort_keys", None)
         use_natural_keys = kwargs.pop("use_natural_keys", None)
         geom_format = kwargs.pop("geom_format", None)
+        force_recalculation = kwargs.pop("force_recalculation", None)
 
         super(HttpResponse, self).__init__(*args, **kwargs)
 
@@ -40,13 +41,19 @@ class JSONResponse(HttpResponse):
             options["use_natural_keys"] = use_natural_keys
         if geom_format is not None:
             options["geom_format"] = geom_format
+        if force_recalculation is not None:
+            options["force_recalculation"] = force_recalculation
 
         # Content is a bytestring. See the `content` property methods.
         self.content = JSONSerializer().serialize(content, **options)
 
 
 class JSONErrorResponse(JSONResponse):
-    def __init__(self, title=None, message=None, content={}, status=500, *args, **kwargs):
+    def __init__(
+        self, title=None, message=None, content=None, status=500, *args, **kwargs
+    ):
+        if not content:
+            content = {}
         try:
             content["status"] = content.get("status", "false")
             content["success"] = content.get("success", False)
@@ -55,7 +62,9 @@ class JSONErrorResponse(JSONResponse):
         except AttributeError as e:
             logger.exception(_("Could not return JSON Response"))
 
-        super(JSONErrorResponse, self).__init__(content=content, status=status, *args, **kwargs)
+        super(JSONErrorResponse, self).__init__(
+            content=content, status=status, *args, **kwargs
+        )
 
 
 class Http401Response(HttpResponse):
