@@ -41,7 +41,7 @@ class BaseManagerView(TemplateView):
         context["graph_models"] = []
         context["graphs"] = "[]"
         context["plugins"] = []
-        for plugin in models.Plugin.objects.all().order_by("sortorder"):
+        for plugin in models.Plugin.objects.all():
             if self.request.user.has_perm("view_plugin", plugin):
                 context["plugins"].append(plugin)
 
@@ -102,14 +102,16 @@ class MapBaseManagerView(BaseManagerView):
     def get_context_data(self, **kwargs):
         context = super(MapBaseManagerView, self).get_context_data(**kwargs)
         datatype_factory = DataTypeFactory()
-        geom_datatypes = [
-            d.pk for d in models.DDataType.objects.filter(isgeometric=True)
-        ]
-        geom_nodes = models.Node.objects.filter(
-            graph__isresource=True,
-            graph__publication__isnull=False,
-            datatype__in=geom_datatypes,
-        ).exclude(graph__graphid=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
+        geom_nodes = (
+            models.Node.objects.filter(
+                graph__isresource=True,
+                graph__is_active=True,
+                graph__source_identifier__isnull=True,
+                datatype__in=models.DDataType.objects.filter(isgeometric=True),
+            )
+            .exclude(graph__graphid=settings.SYSTEM_SETTINGS_RESOURCE_MODEL_ID)
+            .select_related("nodegroup")
+        )
         resource_layers = []
         resource_sources = []
         for node in geom_nodes:
